{% extends 'main/layout.html' %} {% load static %}
<!-- block -->
{% block title %} {{title}} {%endblock title %} {% block content %}
<section class="">
  <div class="content-wrapper">
    <div class="content-heading text-center">
      <div class="row justify-content-around mb-2 mt-5">
        <div class="col-md-2">
          <img class="rounded-circle thumb96" src="{% static 'main/img/rdtl.png' %}" alt="Image" />
        </div>
        <div class="col-md-8">
          <h1 class="text-center">Ministério da Administração Estatal</h1>
          {% comment %} <h3>Diresaun Nasional Apoiu Administrasaun Sukus</h3> {% endcomment %}
          <h4>
            SISTEMA INTEGRADO DE INFORMAÇÃO E GESTÃO DE DADOS DE SUCOS E ALDEIAS
            (SIIGSA)
          </h4>
        </div>

        <div class="col-md-2">
          <img class="rounded-circle thumb96" src="{% static 'main/img/mae.png' %}" alt="Image" />
        </div>
      </div>
      <hr />
      {% if group != 'admin' %}
      <center>
        <h2>
          Bem Vindo Mai Suco: {{objects.village}}
        </h2>
      </center>
      <div class="row mt-5">
        <!-- ADMINISTRASAUN -->
        <div class="col-md-12">
          <div class="row">
            <div class="col-sm-4">
              <div class="card shadow-lg pt-3 rounded pie-chart-example">
                <div class="card-header d-flex align-items-center">
                  <h4>Desizaun Suku</h4>
                </div>
                <div class="card-body">
                  <div class="chart-container">
                    <canvas id="decision_charts" data-url="{% url 'administration:decisionall_charts' %}"></canvas>
                  </div>
                </div>
              </div>
            </div>
            <div class="col-sm-4">
              <div class="card shadow-lg pt-3 rounded pie-chart-example">
                <div class="card-header d-flex align-items-center">
                  <h4>Inventáriu Suku</h4>
                </div>
                <div class="card-body">
                  <div class="chart-container">
                    <canvas id="inventory_charts" data-url="{% url 'administration:inventoryall_charts' %}"></canvas>
                  </div>
                </div>
              </div>
            </div>
            <div class="col-sm-4">
              <div class="card shadow-lg pt-3 rounded pie-chart-example">
                <div class="card-header d-flex align-items-center">
                  <h4>Karta Sai</h4>
                </div>
                <div class="card-body">
                  <div class="chart-container">
                    <canvas id="letterout_charts" data-url="{% url 'administration:letteroutbyyear_charts' %}"></canvas>
                  </div>
                </div>
              </div>
            </div>
            <div class="col-sm-4">
              <div class="card shadow-lg pt-3 rounded pie-chart-example">
                <div class="card-header d-flex align-items-center">
                  <h4>Karta Tama</h4>
                </div>
                <div class="card-body">
                  <div class="chart-container">
                    <canvas id="letterin_charts" data-url="{% url 'administration:letterinbyyear_charts' %}"></canvas>
                  </div>
                </div>
              </div>
            </div>
            <div class="col-sm-4">
              <div class="card shadow-lg pt-3 rounded pie-chart-example">
                <div class="card-header d-flex align-items-center">
                  <h4>Keixa Suku</h4>
                </div>
                <div class="card-body">
                  <div class="chart-container">
                    <canvas id="complaint_charts" data-url="{% url 'administration:complaintbyyear_charts' %}"></canvas>
                  </div>
                </div>
              </div>
            </div>
            <div class="col-sm-4">
              <div class="card shadow-lg pt-3 rounded pie-chart-example">
                <div class="card-header d-flex align-items-center">
                  <h4>Bainaka Suku</h4>
                </div>
                <div class="card-body">
                  <div class="chart-container">
                    <canvas id="visitor_charts" data-url="{% url 'administration:visitorbyyear_charts' %}"></canvas>
                  </div>
                </div>
              </div>
            </div>

          </div>
        </div>
        <!-- POPULASAUN -->
        <div class="col-md-12">
          <div class="row">
            <div class="col-sm-4">
              <div class="card shadow-lg pt-3 rounded pie-chart-example">
                <div class="card-header d-flex align-items-center">
                  <h4>Populasaun Suku</h4>
                </div>
                <div class="card-body">
                  <div class="chart-container">
                    <canvas id="population-chart" data-url="{% url 'population:popchar_genderyear' %}"></canvas>
                  </div>
                </div>
              </div>
            </div>
            <div class="col-sm-4">
              <div class="card shadow-lg pt-3 rounded pie-chart-example">
                <div class="card-header d-flex align-items-center">
                  <h4>Mudansa Populasaun</h4>
                </div>
                <div class="card-body">
                  <div class="chart-container">
                    <canvas id="populationchange-chart" data-url="{% url 'population:popchar_changes' %}"></canvas>
                  </div>
                </div>
              </div>
            </div>
            <div class="col-sm-4">
              <div class="card shadow-lg pt-3 rounded pie-chart-example">
                <div class="card-header d-flex align-items-center">
                  <h4>Populasaun Tempor&aacuteriu</h4>
                </div>
                <div class="card-body">
                  <div class="chart-container">
                    <canvas id="poptemporary-charts" data-url="{% url 'population:popchar_temporary' %}"></canvas>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>


        <div class="col-md-12">
          <div class="row">

            <div class="col-sm-4">
              <div class="card shadow-lg pt-3 rounded pie-chart-example">
                <div class="card-header d-flex align-items-center">
                  <h4>Projetus</h4>
                </div>
                <div class="card-body">
                  <div class="chart-container">
                    <canvas id="project-charts" data-url="{% url 'development:project-charts' %}"></canvas>
                  </div>
                </div>
              </div>
            </div>
            <div class="col-sm-4">
              <div class="card shadow-lg pt-3 rounded pie-chart-example">
                <div class="card-header d-flex align-items-center">
                  <h4>Aktividades</h4>
                </div>
                <div class="card-body">
                  <div class="chart-container">
                    <canvas id="activity-charts" data-url="{% url 'development:activity-charts' %}"></canvas>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
      {%else%}
      <div class="row mt-5">
        <div class="col-md-12">
          <center>
            <h1 class="text-center">Bem Vindo</h1>
            <h4 class="text-center">Ita Bo'ot Login hanesan Admin Nasional</h4>
          </center>
        </div>
        {% endif %}
      </div>
    </div>
</section>


<script src="{% static 'main/js/jquery.min.js' %}"></script>
<script src="{% static 'main/vendor/chart.js/dist/population_chart.js' %}"></script>
<script src="{% static 'main/vendor/chart.js/dist/custom_chart.js' %}"></script>
<script src="{% static 'main/vendor/chart.js/dist/development_chart.js' %}"></script>

{% endblock %}