{% load static %}
<section class="">
  <div class="content-wrapper">
    <div class="content-heading text-center">
      {% comment %}
      <div class="row justify-content-around mb-2">
        <div class="col-md-4">
          <img class="rounded-circle thumb80" src="{% static 'main/img/rdtl.png' %}" alt="Image" />
        </div>
        <div class="col-md-4">
          <img class="rounded-circle thumb80" src="{% static 'main/img/mae.png' %}" alt="Image" />
        </div>
      </div>
      {% endcomment %}
      <h1 class="text-center">Ministério da Administração Estatal</h1>
      {% comment %} <h3>Diresaun Nasional Apoiu Administrasaun ba Sukus</h3> {% endcomment %}
      <h3>SISTEMA INTEGRADO DE INFORMAÇÃO E GESTÃO DE DADOS DE SUCOS E ALDEIAS (SIIGSA)</h3>
      <h4>Municipio: Dili</h4>
      <h5>Posto Administrativo: Dom Aleixo</h5>
      <h5>Suco: Comoro</h5>
    </div>
  </div>
</section>
