<footer class="footer-container bg-dark d-flex justify-content-between">
  <div class="text-white">
    © 2021 Copyright :
    <a href="#" class="mr-1"> MAE</a>
    <a href="{% url 'dashboard' %}">SIIGSA</a>
  </div>
  <small class="text-white">
    Developed by:
    <a href="#" target="_blank">HALONA SERENA</a> jv
    <a href="http://www.kinos.tl/" target="_blank">KINOS</a>
  </small>
</footer>
