{% extends "main/layout.html" %} {% block content %}
<div class="row justify-content-center mt-3">
  <div class="col-sm-6">
    <div class="card shadow-lg pt-3 rounded">
      <div class="card-body text-center">
        <h6 class="font-weight-light my-4">Ita Boot Sai ona husi Sistema</h6>
        <small class="text-muted">
          <a class="btn btn-outline-info btn-sm" href="{% url 'login' %}">Log In <i class="fa fa-arrow-circle-right"></i></a>
        </small>
      </div>
      <!--end card-body-->
    </div>
    <!--end card-->
  </div>
  <!--end col-->
</div>
<!--end row-->
{% endblock %}
