{% load static %}
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8" />
    <meta
      name="viewport"
      content="width=device-width, initial-scale=1, maximum-scale=1"
    />
    <meta name="description" content="Bootstrap Admin App" />
    <meta
      name="keywords"
      content="app, responsive, jquery, bootstrap, dashboard, admin"
    />
    <link
      rel="icon"
      type="image/x-icon"
      href="{% static 'main/img/mae.png' %}"
    />
    <title>SIIGSA - {% block title %}{% endblock title %}</title>
    <!-- =============== VENDOR STYLES ===============-->
    <!-- FONT AWESOME-->
    <script src="{% static 'main/js/jquery.min.js'%}"></script>
    <link
      rel="stylesheet"
      href=" {% static 'main/vendor/@fortawesome/fontawesome-free/css/brands.css' %} "
    />
    <link
      rel="stylesheet"
      href="{% static 'main/vendor/@fortawesome/fontawesome-free/css/regular.css' %}"
    />
    <link
      rel="stylesheet"
      href="{% static 'main/vendor/@fortawesome/fontawesome-free/css/solid.css' %}"
    />
    <link
      rel="stylesheet"
      href="{% static 'main/vendor/@fortawesome/fontawesome-free/css/fontawesome.css' %}"
    />
    <!-- SIMPLE LINE ICONS-->
    <link
      rel="stylesheet"
      href="{% static 'main/vendor/simple-line-icons/css/simple-line-icons.css' %}"
    />
    <!-- ANIMATE.CSS-->
    <!-- <link
      rel="stylesheet"
      href="{% static 'main/vendor/animate.css/animate.css' %}"
    /> -->
    <!-- WHIRL (spinners)-->
    <!-- <link
      rel="stylesheet"
      href="{% static 'main/vendor/whirl/dist/whirl.css' %}"
    /> -->

    <!-- =============== PAGE VENDOR STYLES ===============-->
    <!-- WEATHER ICONS-->
    <!-- <link
      rel="stylesheet"
      href="{% static 'main/vendor/weather-icons/css/weather-icons.css' %}"
    /> -->
    <!-- <link rel="stylesheet" href="{% static 'vendor/datatables.net-keytable-bs/css/keyTable.bootstrap.css' %}"> -->
    <!-- <link rel="stylesheet" href="{% static 'vendor/datatables.net-responsive-bs/css/responsive.bootstrap.css' %}"> -->
      <!-- <link rel="stylesheet" href=" {% static 'vendor/datatables.net-bs4/css/dataTables.bootstrap4.css' %} ">  -->
    <!-- =============== BOOTSTRAP STYLES ===============-->
    <!-- Uza iha module Administrasaun -->
    <link rel="stylesheet" href="{% static 'main/vendor/bootstrap-tagsinput/dist/bootstrap-tagsinput.css' %}"> 
    <link rel="stylesheet" href="{% static 'main/vendor/select2/dist/css/select2.css' %}">
    <link rel="stylesheet" href="{% static 'main/vendor/@ttskch/select2-bootstrap4-theme/dist/select2-bootstrap4.css' %}">

           <link
      rel="stylesheet"
      href="{% static 'main/vendor/choosen/chosenstyle.css' %}"
    />

    
    <!-- end Uza iha module Administrasaun -->
    <link
      rel="stylesheet"
      href="{% static 'main/css/bootstrap.css' %}"
      id="bscss"
    />
    <!-- =============== APP STYLES ===============-->
    <link
      rel="stylesheet"
      href="{% static 'main/css/app.css' %}"
      id="maincss"
    />
    <style type="text/css">
        .asteriskField{
            display: none;
        }
    </style>
  </head>

  <body>
    <div class="wrapper">
      <!-- top navbar-->
      {% include 'main/navbar.html' %} {% block content %}{% endblock content %}
      {% comment %} {% include 'main/footer.html' %} {% endcomment %}


    <!-- =============== VENDOR SCRIPTS ===============-->
    <!-- MODERNIZR-->
    <!-- <script src="{% static 'main/vendor/modernizr/modernizr.custom.js' %}"></script> -->
    <!-- STORAGE API-->
    <!-- <script src="{% static 'main/vendor/js-storage/js.storage.js' %}"></script> -->
    <!-- i18next-->
    <!-- {% comment %}
    <script src="{% static 'main/vendor/i18next/i18next.js' %}"></script>
    <script src="{% static 'main/vendor/i18next-xhr-backend/i18nextXHRBackend.js' %}"></script>
    <script src="{% static 'main/vendor/popper.js' %}/dist/umd/popper.js' %}"></script>
    {% endcomment %} -->

    <script src="{% static 'main/vendor/jquery/dist/jquery.js' %}"></script>
    <script src="{% static 'main/vendor/bootstrap/dist/js/bootstrap.js' %}"></script>

    <!-- =============== PAGE VENDOR SCRIPTS ===============-->

    <!-- Datatables-->
      
    <script src="{% static 'main/vendor/datatables.net/js/jquery.dataTables.js' %}"></script>
    <script src="{% static 'main/vendor/datatables.net-bs4/js/dataTables.bootstrap4.js' %}"></script>
    <!--<script src="{% static 'main/vendor/datatables.net-buttons/js/dataTables.buttons.js' %}"></script>
    <script src="{% static 'main/vendor/datatables.net-buttons-bs/js/buttons.bootstrap.js' %}"></script>
    <script src="{% static 'main/vendor/datatables.net-buttons/js/buttons.colVis.js' %}"></script>
    <script src="{% static 'main/vendor/datatables.net-buttons/js/buttons.flash.js' %}"></script>
    <script src="{% static 'main/vendor/datatables.net-buttons/js/buttons.html5.js' %}"></script> -->
    {% comment %} <script src="{% static 'main/vendor/datatables.net-buttons/js/buttons.print.js' %}"></script> {% endcomment %}
    <!-- <script src="{% static 'main/vendor/datatables.net-keytable/js/dataTables.keyTable.js' %}"></script>
    <script src="{% static 'main/vendor/datatables.net-responsive/js/dataTables.responsive.js' %}"></script>
    <script src="{% static 'main/vendor/datatables.net-responsive-bs/js/responsive.bootstrap.js' %}"></script> -->
    
    <!-- <script src="{% static 'main/vendor/jszip/dist/jszip.js' %}"></script> -->
    {% comment %} <script src="{% static 'main/vendor/pdfmake/build/pdfmake.js' %}"></script> {% endcomment %}
    <!-- <script src="{% static 'main/vendor/pdfmake/build/vfs_fonts.js' %}"></script> -->
    
    
    <script src="{% static 'main/vendor/select2/dist/js/select2.full.js' %}"></script> 
    <!-- CHART.JS-->
    <script src="{% static 'main/vendor/chart.js/dist/Chart.js' %}"></script>
    <!-- =============== APP SCRIPTS ===============-->
    <script src="{% static 'main/js/app.js' %}"></script>
    <script type="text/javascript">
      function hidediv() {
        document.getElementById("divmessage").remove();
      }
      setTimeout("hidediv()", 5000);
    </script>

    {% block scripts %} {% endblock scripts %}
  </body>
</html>
